# Overview

[![PyPI Status](https://badge.fury.io/py/seveno-pyutil.svg)](https://badge.fury.io/py/seveno-pyutil)
[![license](https://img.shields.io/pypi/l/seveno_pyutil.svg)](https://opensource.org/licenses/MIT)
[![tests](https://github.com/tadams42/seveno_pyutil/actions/workflows/tests.yaml/badge.svg?branch=development)](https://github.com/tadams42/seveno_pyutil/actions/workflows/tests.yaml)
[![codecov](https://codecov.io/gh/tadams42/seveno_pyutil/branch/development/graph/badge.svg?token=9WIWK7B3XX)](https://codecov.io/gh/tadams42/seveno_pyutil)
[![Documentation Status](https://readthedocs.org/projects/seveno-pyutil/badge/?version=latest)](http://seveno-pyutil.readthedocs.io/en/latest/?badge=latest)
[![python_versions](https://img.shields.io/pypi/pyversions/seveno_pyutil.svg)](https://pypi.org/project/seveno_pyutil/)

Various unsorted Python utilities. [Examples of usage](https://seveno-pyutil.readthedocs.io/en/latest/examples_and_usage.html)

## Installation

~~~sh
pip install seveno_pyutil
~~~

## Tests

~~~sh
py.test
~~~

## Development mode

Install with extra dev packages

~~~sh
pip install -e .[dev,tests]
~~~
